@@ -3,8 +3,6 @@
 # @(#) Fibranet NSP, SL
 # Copyright (C) 2005 by Jordi Sanfeliu <admin@fibranet.com>
 #
-# Monitorix v3.0
-#
 
 use strict;
 use warnings;
@@ -13,7 +11,7 @@ use File::Copy;
 use IO::Socket;
 use RRDs;
 
-our $MONITORIX_VER = "0.7.11";
+our $MONITORIX_VER = "0.7.12";
 our $TITLE;
 our $SAMBAVER;
 our $MULTIHOST;
@@ -1506,13 +1504,14 @@ sub servu {
 	my $MAIL_LOG="/var/log/maillog";
 	my $HTTP_LOG="/var/log/httpd/access_log";
 	my $FAX_LOG="/var/spool/hylafax/etc/xferfaxlog";
-	my $SMBSTATUS="smbstatus";
+	my $SMBSTATUS=`which smbstatus 2>/dev/null`;
+	chomp($SMBSTATUS);
 	my $DATE_STR=`date '+\%b \%e'`;
 	my $DATE_WWW=`date +\%d/\%b/\%Y`;
 	my $DATE_FAX=`date +\%m/\%d/\%y`;
-	chomp $DATE_STR;
-	chomp $DATE_WWW;
-	chomp $DATE_FAX;
+	chomp($DATE_STR);
+	chomp($DATE_WWW);
+	chomp($DATE_FAX);
 	my $POP3=0;
 	my $FTP=0;
 	my $TELNET=0;
@@ -1674,8 +1673,10 @@ sub port {
 sub user {
 	my $SMB=0;
 	my $MAC=0;
-	my $SMBSTATUS="smbstatus";
-	my $MACUSERS="macusers";
+	my $SMBSTATUS=`which smbstatus 2>/dev/null`;
+	chomp($SMBSTATUS);
+	my $MACUSERS=`which macusers 2>/dev/null`;
+	chomp($MACUSERS);
 	my $USR=`who -q | grep users | sed 's/^.*=//'`;
 	my $rrdata="N";
 
@@ -1784,8 +1785,8 @@ sub temp_ML310 {
 		$SB=`cat /proc/cpqtemp | grep "System Board" | awk -F " " '{ print \$7 }' | sed s'/C//'`;
 		$CPU1=`cat /proc/cpqtemp | grep "CPU (1)" | awk -F " " '{ print \$7 }' | sed s'/C//'`;
 	} else {
-		$SB=`hplog -t | grep "System Board" | awk -F " " '{ print \$7 }' | sed s'/C//'`;
-		$CPU1=`hplog -t | grep "CPU (1)" | awk -F " " '{ print \$7 }' | sed s'/C//'`;
+		$SB=`/sbin/hplog -t | grep "System Board" | awk -F " " '{ print \$7 }' | sed s'/C//'`;
+		$CPU1=`/sbin/hplog -t | grep "CPU (1)" | awk -F " " '{ print \$7 }' | sed s'/C//'`;
 	}
         
 	chomp($SB);
@@ -1807,9 +1808,9 @@ sub temp_ML350G3 {
 		$CPU1=`cat /proc/cpqtemp | grep "CPU (1)" | awk -F " " '{ print \$7 }' | sed s'/C//'`;
 		$CPU2=`cat /proc/cpqtemp | grep "CPU (2)" | awk -F " " '{ print \$7 }' | sed s'/C//'`;
 	} else {
-		$SB=`hplog -t | grep "System Board" | awk -F " " '{ print \$7 }' | sed s'/C//'`;
-		$CPU1=`hplog -t | grep "CPU (1)" | awk -F " " '{ print \$7 }' | sed s'/C//'`;
-		$CPU2=`hplog -t | grep "CPU (2)" | awk -F " " '{ print \$7 }' | sed s'/C//'`;
+		$SB=`/sbin/hplog -t | grep "System Board" | awk -F " " '{ print \$7 }' | sed s'/C//'`;
+		$CPU1=`/sbin/hplog -t | grep "CPU (1)" | awk -F " " '{ print \$7 }' | sed s'/C//'`;
+		$CPU2=`/sbin/hplog -t | grep "CPU (2)" | awk -F " " '{ print \$7 }' | sed s'/C//'`;
 	}
 
 	chomp($SB);
@@ -1842,14 +1843,14 @@ sub temp_ML570 {
 		$SCS1=`cat /proc/cpqtemp | grep "7  LM75 Sensor" | awk -F " " '{ print \$8 }' | sed s'/C.*\$//'`;
 		$SCS2=`cat /proc/cpqtemp | grep "8  LM75 Sensor" | awk -F " " '{ print \$8 }' | sed s'/C.*\$//'`;
 	} else {
-		$CPU1=`hplog -t | grep "CPU (1)" | awk -F " " '{ print \$8 }' | sed s'/C.*\$//'`;
-		$CPU2=`hplog -t | grep "CPU (2)" | awk -F " " '{ print \$8 }' | sed s'/C.*\$//'`;
-		$CPU3=`hplog -t | grep "CPU (4)" | tr "-" " " | awk -F " " '{ print \$8 }' | sed s'/C.*\$//'`;
-		$CPU4=`hplog -t | grep "CPU (8)" | tr "-" " " | awk -F " " '{ print \$8 }' | sed s'/C.*\$//'`;
-		$SB1=`hplog -t | grep "5  LM75 Sensor" | awk -F " " '{ print \$8 }' | sed s'/C.*\$//'`;
-		$SB2=`hplog -t | grep "6  LM75 Sensor" | awk -F " " '{ print \$8 }' | sed s'/C.*\$//'`;
-		$SCS1=`hplog -t | grep "7  LM75 Sensor" | awk -F " " '{ print \$8 }' | sed s'/C.*\$//'`;
-		$SCS2=`hplog -t | grep "8  LM75 Sensor" | awk -F " " '{ print \$8 }' | sed s'/C.*\$//'`;
+		$CPU1=`/sbin/hplog -t | grep "CPU (1)" | awk -F " " '{ print \$8 }' | sed s'/C.*\$//'`;
+		$CPU2=`/sbin/hplog -t | grep "CPU (2)" | awk -F " " '{ print \$8 }' | sed s'/C.*\$//'`;
+		$CPU3=`/sbin/hplog -t | grep "CPU (4)" | tr "-" " " | awk -F " " '{ print \$8 }' | sed s'/C.*\$//'`;
+		$CPU4=`/sbin/hplog -t | grep "CPU (8)" | tr "-" " " | awk -F " " '{ print \$8 }' | sed s'/C.*\$//'`;
+		$SB1=`/sbin/hplog -t | grep "5  LM75 Sensor" | awk -F " " '{ print \$8 }' | sed s'/C.*\$//'`;
+		$SB2=`/sbin/hplog -t | grep "6  LM75 Sensor" | awk -F " " '{ print \$8 }' | sed s'/C.*\$//'`;
+		$SCS1=`/sbin/hplog -t | grep "7  LM75 Sensor" | awk -F " " '{ print \$8 }' | sed s'/C.*\$//'`;
+		$SCS2=`/sbin/hplog -t | grep "8  LM75 Sensor" | awk -F " " '{ print \$8 }' | sed s'/C.*\$//'`;
 	}
 
 	chomp($CPU1);
