@@ -3,9 +3,8 @@
 # @(#) Fibranet NSP, SL
 # Copyright (C) 2005 by Jordi Sanfeliu <admin@fibranet.com>
 #
-# Monitorix v3
 
-* * * * * root /usr/sbin/monitorix.pl update
+* * * * * root ps -C monitorix.pl --no-headers || /usr/sbin/monitorix.pl update
 00 00 * * * root /usr/sbin/monitorix.pl collect
 01 00 1 * * root /usr/sbin/monitorix.pl report
 
